---
myst:
  html_meta:
    "description": "cs_dynamicpages Reference"
    "property=og:description": "cs_dynamicpages Reference"
    "property=og:title": "cs_dynamicpages Reference"
    "keywords": "Plone, _cs_dynamicpages,_ reference"
---

# Reference

This part of the documentation contains reference material, including APIs, configuration values, and environment variables.

> Reference guides are technical descriptions of the machinery and how to operate it.
> Reference material is information-oriented.

```{seealso}
https://diataxis.fr/reference/
```

```{toctree}
:maxdepth: 2

built-in-views
behaviors
```
